@@ -18,7 +18,7 @@ impl Default for UeInstance {
 }
 
 impl UeInstance {
-    pub fn draw_cover_ueberzug(&self, url: &str, draw_xywh: &Xywh) -> Result<()> {
+    pub fn draw_cover_ueberzug(&self, url: &str, draw_xywh: &Xywh, use_sixel: bool) -> Result<()> {
         if draw_xywh.width <= 1 || draw_xywh.height <= 1 {
             return Ok(());
         }
@@ -39,6 +39,14 @@ impl UeInstance {
         //     "draw_xywh.x = {}, draw_xywh.y = {}, draw_wyxh.width = {}, draw_wyxh.height = {}",
         //     draw_xywh.x, draw_xywh.y, draw_xywh.width, draw_xywh.height,
         // );
+        if use_sixel {
+            if let Err(e) = self.run_ueberzug_cmd_sixel(&cmd) {
+                bail!("Failed to run Ueberzug: {}", e)
+                // Ok(())
+            }
+            return Ok(());
+        }
+
         if let Err(e) = self.run_ueberzug_cmd(&cmd) {
             bail!("Failed to run Ueberzug: {}", e)
             // Ok(())
@@ -58,6 +66,8 @@ impl UeInstance {
     fn run_ueberzug_cmd(&self, cmd: &str) -> Result<()> {
         let mut ueberzug = self.ueberzug.write().unwrap();
 
+        // eprintln!("using x11 output for ueberzugpp");
+
         if ueberzug.is_none() {
             *ueberzug = Some(
                 std::process::Command::new("ueberzug")
@@ -73,4 +83,28 @@ impl UeInstance {
 
         Ok(())
     }
+
+    fn run_ueberzug_cmd_sixel(&self, cmd: &str) -> Result<()> {
+        let mut ueberzug = self.ueberzug.write().unwrap();
+
+        // eprintln!("using sixel output for ueberzugpp");
+
+        if ueberzug.is_none() {
+            *ueberzug = Some(
+                std::process::Command::new("ueberzug")
+                    .args(["layer", "--silent"])
+                    // .args(["layer", "--silent", "--no-cache", "--output", "sixel"])
+                    // .args(["layer", "--sixel"])
+                    // .args(["--sixel"])
+                    .stdin(Stdio::piped())
+                    .stdout(Stdio::piped())
+                    .spawn()?,
+            );
+        }
+
+        let stdin = (*ueberzug).as_mut().unwrap().stdin.as_mut().unwrap();
+        stdin.write_all(cmd.as_bytes())?;
+
+        Ok(())
+    }
 }
